@@ -72,6 +72,8 @@ class LiveClient(WebSocketApp):
             self.add_contract_details(msg['symbollist'])
         if msg['message'] == 'symbols removed':
             pass
+        if msg['message'] == "Invalid User Credentials":
+            print(f'{Style.BRIGHT}{Fore.RED}Connection failed due to Invalid User Credentials...{Style.RESET_ALL}')
 
     def add_contract_details(self, contracts_list):
         for contract in contracts_list:
@@ -180,7 +182,11 @@ class HistoricalWebsocket:
             broker_append = f'&brokertoken={self.broker_token}'
         self.hist_socket = create_connection(f"wss://{self.url}:{self.historical_port}?user={self.login_id}&password={self.password}{broker_append}")
         welcome_msg = self.hist_socket.recv()
-        print(f"Connected successfully to '{json.loads(welcome_msg)['message']}'")
+        welcome_msg = json.loads(welcome_msg)
+        if welcome_msg['success']:
+            print(f"Connected successfully to {welcome_msg['message']}")
+        else:
+            print(f"{Style.BRIGHT}{Fore.RED}Failed to connect with error message = {welcome_msg['message']}{Style.RESET_ALL}")
 
     def get_hist_bar_data(self, contract, query_time, start_time, bar_size):
         # print(f'{{"method": "gethistory", "interval": "{bar_size}", "symbol": "{contract}", "from": "{start_time}", "to": "{query_time}"}}')
